//##protect##"FileHeader"
/** @file Get1DigitalOutputStatus.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 03.12.2012
 *  @date    $LastChangedDate: 2012-12-07 10:36:45 +0100 (Fr, 07. Dez 2012) $
 *  @version $LastChangedRevision: 3640 $
 *
 *  @par DESCRIPTION
 *  Gets the status of one digital output 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "StdAfx.h"

//##protect##"Get1DigitalOutputStatus_Head"
//##protect##"Get1DigitalOutputStatus_Head"

int _tmain(int argc, _TCHAR *argv[])
{
	INT    i_ReturnValue = 0;
	HANDLE h_BoardHandle = NULL;
//##protect##"Get1DigitalOutputStatus_VariablesDeclaration"
	BYTE   b_OutputMemory = 0;
	BYTE   b_Channel = 0;
	BYTE   b_Status = 0;
//##protect##"Get1DigitalOutputStatus_VariablesDeclaration"

	UNREFERENCED_PARAMETER(argc);
	UNREFERENCED_PARAMETER(argv);

	printf("/****************************************************************************\\\n"
	       "|*                      Get1DigitalOutputStatus sample                      *|\n"
	       "|****************************************************************************|\n"
	       "|* Gets the status of one digital output                                    *|\n"
	       "\\****************************************************************************/\n\n");

//##protect##"Get1DigitalOutputStatus_Start"
//##protect##"Get1DigitalOutputStatus_Start"

	i_ReturnValue = i_Utils_OpenBoard(&h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_Utils_OpenBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"Get1DigitalOutputStatus_Body"
	/* Set off all the digital outputs before doing anything */
	i_ReturnValue = i_PCIe1516_SetAllDigitalOutputs(h_BoardHandle, 0);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
		i_PCIe1516_CloseBoard(h_BoardHandle);
		_getch();
		return i_ReturnValue;
	}

	b_OutputMemory = (BYTE)ll_Utils_ReadInteger(0, 1, "Do you want to use the output memory (0 for no, 1 for yes)?");
	if (b_OutputMemory)
	{
		i_ReturnValue = i_PCIe1516_SetDigitalOutputMemoryOn(h_BoardHandle);

		if (i_ReturnValue != 0)
		{
			fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
			i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return i_ReturnValue;
		}
	}

	do
	{
		b_Channel = (BYTE)ll_Utils_ReadInteger(0, 7, "Which channel do you want the status of (0 to 7)?");	
		i_ReturnValue = i_PCIe1516_Set1DigitalOutputOn(h_BoardHandle, b_Channel);
		if (i_ReturnValue != 0)
		{
			fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
			i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return i_ReturnValue;
		}

		i_ReturnValue = i_PCIe1516_Get1DigitalOutputStatus(h_BoardHandle, b_Channel, &b_Status);
		if(i_ReturnValue != 0)
		{
			fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
			i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return i_ReturnValue;
		}

		printf("Channel %d set on. \n", b_Channel);
		printf("Status of the channel %d: 0x%x. \n", b_Channel, b_Status);

		if (b_OutputMemory)
		{
			Sleep(200);
			i_ReturnValue = i_PCIe1516_Set1DigitalOutputOff(h_BoardHandle, b_Channel);
			if (i_ReturnValue != 0)
			{
				fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
				i_PCIe1516_CloseBoard(h_BoardHandle);
				_getch();
				return i_ReturnValue;
			}

			i_ReturnValue = i_PCIe1516_Get1DigitalOutputStatus(h_BoardHandle, b_Channel, &b_Status);
			if(i_ReturnValue != 0)
			{
				fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
				i_PCIe1516_CloseBoard(h_BoardHandle);
				_getch();
				return i_ReturnValue;
			}

			printf("Channel %d set off. \n", b_Channel);
			printf("Status of the channel %d: 0x%x. \n", b_Channel, b_Status);
		}
	} while (ll_Utils_ReadInteger(0, 1, "Do you want to get the status of another channel (0 for no, 1 for yes)?") != 0);

	if (b_OutputMemory)
	{
		i_ReturnValue = i_PCIe1516_SetDigitalOutputMemoryOff(h_BoardHandle);
			if (i_ReturnValue != 0)
			{
				fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
				i_PCIe1516_CloseBoard(h_BoardHandle);
				_getch();
				return i_ReturnValue;
			}
	}
//##protect##"Get1DigitalOutputStatus_Body"

	i_ReturnValue = i_PCIe1516_CloseBoard(h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_PCIe1516_CloseBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"Get1DigitalOutputStatus_End"
//##protect##"Get1DigitalOutputStatus_End"

	printf("\nPress any key to exit the sample...\n");
	_getch();
	return i_ReturnValue;
}
