//##protect##"FileHeader"
/** @file Set1DigitalOutput.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 03.12.2012
 *  @date    $LastChangedDate: 2013-01-24 14:46:43 +0100 (Do, 24. Jan 2013) $
 *  @version $LastChangedRevision: 3720 $
 *
 *  @par DESCRIPTION
 *  Sets one digital output of the board 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "StdAfx.h"

//##protect##"Set1DigitalOutput_Head"
//##protect##"Set1DigitalOutput_Head"

int _tmain(int argc, _TCHAR *argv[])
{
	INT    i_ReturnValue = 0;
	HANDLE h_BoardHandle = NULL;
//##protect##"Set1DigitalOutput_VariablesDeclaration"
	DWORD  dw_Temp = 0;
	BYTE   b_OutputMemory = 0;
//##protect##"Set1DigitalOutput_VariablesDeclaration"

	UNREFERENCED_PARAMETER(argc);
	UNREFERENCED_PARAMETER(argv);

	printf("/****************************************************************************\\\n"
	       "|*                         Set1DigitalOutput sample                         *|\n"
	       "|****************************************************************************|\n"
	       "|* Sets one digital output of the board                                     *|\n"
	       "\\****************************************************************************/\n\n");

//##protect##"Set1DigitalOutput_Start"
//##protect##"Set1DigitalOutput_Start"

	i_ReturnValue = i_Utils_OpenBoard(&h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_Utils_OpenBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"Set1DigitalOutput_Body"
	do
	{
		printf("Use output memory (0 for no, 1 for yes): ");
		scanf_s("%lu", &dw_Temp);
	} while (dw_Temp > 1);
	b_OutputMemory = (BYTE)dw_Temp;

	if (b_OutputMemory == 1)
	{
		i_ReturnValue = i_PCIe1516_SetDigitalOutputMemoryOn(h_BoardHandle);
		if (i_ReturnValue != 0)
		{
			printf("i_PCIe1516_SetDigitalOutputMemoryOn error: %d\n", i_ReturnValue);
			i_ReturnValue = i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return 0;
		}
		printf("i_PCIe1516_SetDigitalOutputMemoryOn OK.\n");
	}
	else
	{
		i_ReturnValue = i_PCIe1516_SetDigitalOutputMemoryOff(h_BoardHandle);
		if (i_ReturnValue != 0)
		{
			printf("\n i_PCIe1516_SetDigitalOutputMemoryOff error: %d", i_ReturnValue);
			i_ReturnValue = i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return 0;
		}
		printf("i_PCIe1516_SetDigitalOutputMemoryOff OK.\n");
	}

	for (;;)
	{
		BYTE b_Channel = 0;
		BYTE b_State = 0;

		do
		{
			printf("Enter the channel to set (0 to 7): ");
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 7);
		b_Channel = (BYTE)dw_Temp;

		if (b_OutputMemory == 1)
		{
			do
			{
				printf("Enter the state to set on channel %d (0 for off, 1 for on): ", b_Channel);
				scanf_s("%lu", &dw_Temp);
			} while ((dw_Temp < 0) || (dw_Temp > 1));
			b_State = (BYTE)dw_Temp;
		}
		else
			b_State = 1;

		if (b_State == 1)
		{
			i_ReturnValue = i_PCIe1516_Set1DigitalOutputOn(h_BoardHandle, b_Channel);
			if (i_ReturnValue != 0)
			{
				printf("i_PCIe1516_Set1DigitalOutputOn error: %d\n", i_ReturnValue);
				break;
			}
			else
				printf("i_PCIe1516_Set1DigitalOutputOn OK.\n");
		}
		else
		{
			i_ReturnValue = i_PCIe1516_Set1DigitalOutputOff(h_BoardHandle, b_Channel);
			if (i_ReturnValue != 0)
			{
				printf("i_PCIe1516_Set1DigitalOutputOff error: %d\n", i_ReturnValue);
				break;
			}
			else
				printf("i_PCIe1516_Set1DigitalOutputOff OK.\n");
		}

		do
		{
			printf("Set another channel (0 for yes, 1 for no): ");
			scanf_s("%lu", &dw_Temp);
		} while (dw_Temp > 1);
		if (dw_Temp == 1)
			break;
	}
//##protect##"Set1DigitalOutput_Body"

	i_ReturnValue = i_PCIe1516_CloseBoard(h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_PCIe1516_CloseBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"Set1DigitalOutput_End"
//##protect##"Set1DigitalOutput_End"

	printf("\nPress any key to exit the sample...\n");
	_getch();
	return i_ReturnValue;
}
