//##protect##"FileHeader"
/** @file Set4DigitalOutputs.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 03.12.2012
 *  @date    $LastChangedDate: 2012-12-07 10:36:45 +0100 (Fr, 07. Dez 2012) $
 *  @version $LastChangedRevision: 3640 $
 *
 *  @par DESCRIPTION
 *  Sets four digital outputs of the board 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "StdAfx.h"

//##protect##"Set4DigitalOutputs_Head"
//##protect##"Set4DigitalOutputs_Head"

int _tmain(int argc, _TCHAR *argv[])
{
	INT    i_ReturnValue = 0;
	HANDLE h_BoardHandle = NULL;
//##protect##"Set4DigitalOutputs_VariablesDeclaration"
	BYTE   b_Port = 0;
	BYTE   b_OutputMemory = 0;
	BYTE   b_Channel = 0;
//##protect##"Set4DigitalOutputs_VariablesDeclaration"

	UNREFERENCED_PARAMETER(argc);
	UNREFERENCED_PARAMETER(argv);

	printf("/****************************************************************************\\\n"
	       "|*                        Set4DigitalOutputs sample                         *|\n"
	       "|****************************************************************************|\n"
	       "|* Sets four digital outputs of the board                                   *|\n"
	       "\\****************************************************************************/\n\n");

//##protect##"Set4DigitalOutputs_Start"
//##protect##"Set4DigitalOutputs_Start"

	i_ReturnValue = i_Utils_OpenBoard(&h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_Utils_OpenBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"Set4DigitalOutputs_Body"
	b_Port = (BYTE)ll_Utils_ReadInteger(0, 1, "Which port do you want to set (0 or 1)?");
	b_OutputMemory = (BYTE)ll_Utils_ReadInteger(0, 1, "Do you want to enable output memory (0 for no, 1 for yes)?");
	if (b_OutputMemory == 1)
		i_ReturnValue = i_PCIe1516_SetDigitalOutputMemoryOn(h_BoardHandle);
	else
		i_ReturnValue = i_PCIe1516_SetDigitalOutputMemoryOff(h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "%s \n", pc_PCIe1516_GetLastError(h_BoardHandle));
		i_PCIe1516_CloseBoard(h_BoardHandle);
		_getch();
		return i_ReturnValue;
	}

	while (b_Channel < 4)
	{
		i_ReturnValue = i_PCIe1516_Set4DigitalOutputsOn(h_BoardHandle, b_Port, (1 << b_Channel));
		if (i_ReturnValue != 0)
			break;
		printf("Channel %d on port %d set on. \n", b_Channel, b_Port);

		b_Channel++;
		Sleep(100);
	}
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
		i_PCIe1516_CloseBoard(h_BoardHandle);
		_getch();
		return i_ReturnValue;
	}

	if (b_OutputMemory == 1)
	{
		b_Channel = 0;

		while (b_Channel < 4)
		{
			i_ReturnValue = i_PCIe1516_Set4DigitalOutputsOff(h_BoardHandle, b_Port, (1 << b_Channel));
			if (i_ReturnValue != 0)
				break;
			printf("Channel %d on port %d set off. \n", b_Channel, b_Port);

			b_Channel++;
			Sleep(100);
		}
		if (i_ReturnValue != 0)
		{
			fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
			i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return i_ReturnValue;
		}

		i_ReturnValue = i_PCIe1516_SetDigitalOutputMemoryOff(h_BoardHandle);
		if (i_ReturnValue != 0)
		{
			fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
			i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return i_ReturnValue;
		}
	}
//##protect##"Set4DigitalOutputs_Body"

	i_ReturnValue = i_PCIe1516_CloseBoard(h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_PCIe1516_CloseBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"Set4DigitalOutputs_End"
//##protect##"Set4DigitalOutputs_End"

	printf("\nPress any key to exit the sample...\n");
	_getch();
	return i_ReturnValue;
}
