//##protect##"FileHeader"
/** @file SetAllDigitalOutputs.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 03.12.2012
 *  @date    $LastChangedDate: 2012-12-07 10:36:45 +0100 (Fr, 07. Dez 2012) $
 *  @version $LastChangedRevision: 3640 $
 *
 *  @par DESCRIPTION
 *  Sets all the digital outputs of the board  
 *   within using the digital output memeory 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "StdAfx.h"

//##protect##"SetAllDigitalOutputs_Head"
//##protect##"SetAllDigitalOutputs_Head"

int _tmain(int argc, _TCHAR *argv[])
{
	INT    i_ReturnValue = 0;
	HANDLE h_BoardHandle = NULL;
//##protect##"SetAllDigitalOutputs_VariablesDeclaration"
	BYTE   b_Mask = 0;
	BYTE   b_Status = 0;
	INT    i = 0;
//##protect##"SetAllDigitalOutputs_VariablesDeclaration"

	UNREFERENCED_PARAMETER(argc);
	UNREFERENCED_PARAMETER(argv);

	printf("/****************************************************************************\\\n"
	       "|*                       SetAllDigitalOutputs sample                        *|\n"
	       "|****************************************************************************|\n"
	       "|* Sets all the digital outputs of the board without using the digital      *|\n"
	       "|* output memory                                                            *|\n"
	       "\\****************************************************************************/\n\n");

//##protect##"SetAllDigitalOutputs_Start"
//##protect##"SetAllDigitalOutputs_Start"

	i_ReturnValue = i_Utils_OpenBoard(&h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_Utils_OpenBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"SetAllDigitalOutputs_Body"
	do
	{
		b_Mask = (BYTE)ll_Utils_ReadInteger(0, 255, "Which value do you want to set on the digital outputs (from 0 to 255)?");
		i_ReturnValue = i_PCIe1516_SetAllDigitalOutputs(h_BoardHandle, b_Mask);
		if (i_ReturnValue != 0)
			break;
		i_ReturnValue = i_PCIe1516_Get8DigitalOutputsStatus(h_BoardHandle, &b_Status);
		
		/* Print the status of each output */
		printf("\nCurrent output status:\n");
		printf("_________________________________\n");
		printf("|");
		for (i = 0; i < 8; i++)
			printf(" %d |", i);
		printf("\n");
		printf("|");
		for (i = 0; i < 8; i++)
			printf(" %d |", (b_Status >> i) & 1);
		printf("\n");

	} while (ll_Utils_ReadInteger(0, 1, "Do you want to set another value (0 for no, 1 for yes)?") != 0);

	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
		i_PCIe1516_CloseBoard(h_BoardHandle);
		_getch();
		return i_ReturnValue;
	}
//##protect##"SetAllDigitalOutputs_Body"

	i_ReturnValue = i_PCIe1516_CloseBoard(h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_PCIe1516_CloseBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"SetAllDigitalOutputs_End"
//##protect##"SetAllDigitalOutputs_End"

	printf("\nPress any key to exit the sample...\n");
	_getch();
	return i_ReturnValue;
}
