//##protect##"FileHeader"
/** @file PCIe1516.h
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 27.11.2012
 *  @date    $LastChangedDate: 2012-12-07 14:22:54 +0100 (Fr, 07. Dez 2012) $
 *  @version $LastChangedRevision: 3643 $
 *
 *  @par DESCRIPTION
 *  Main xPCIe1516 header file
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include <windows.h>
#include "define.h"

//##protect##"UserHeaderBegin"
//##protect##"UserHeaderBegin"

#ifdef __cplusplus
extern "C"
{
#endif

/** \defgroup PCIe1516 xPCIe1516 functions
 * @{
 */

/**		\addtogroup General xPCIe1516 General functions
 * 		\ingroup PCIe1516
 *		@{
 */

/* i_PCIe1516_GetNumberOfBoards */
/**
 * Returns the number of xPCIe1516 boards present in the system. \n
 * The function fills the value pointed by pb_NbrOfBoards with the number of boards present.
 *
 * @param[out]  pb_NbrOfBoards Value that will be filled with the number of boards
 * @retval  0   No error
 * @retval -1   Error while getting the number of boards
 */
_INT_ i_PCIe1516_GetNumberOfBoards(OUT BYTE *pb_NbrOfBoards);


/* i_PCIe1516_GetBoardInformation */
/**
 * Gets generic device information.
 *
 * @param[in]   b_BoardIndex Index of the board
 * @param[in]   dw_IdentifierStringSize Size of the identifier parameter buffer
 * @param[out]  pc_Identifier Identifier of the board
 * @param[out]  pdw_UINumber This number is typically a user-perceived slot number, such as a number printed next to the slot on the board, or some other number that makes locating the physical device easier for the user. If the device is on a bus that has no UI number convention, or if the bus driver for the device cannot determine the UI number, this value is 0xFFFFFFFF.
 * @param[out]  pdw_DeviceNumber Device number.
 * @param[out]  pdw_BusNumber Bus number.
 * @param[out]  pdw_BaseAddress0 Base address 0 of the board
 * @param[out]  pdw_BaseAddress1 Base address 1 of the board
 * @param[out]  pdw_BaseAddress2 Base address 2 of the board
 * @param[out]  pdw_BaseAddress3 Base address 3 of the board
 * @param[out]  pb_Interrupt Interrupt line of the board
 * @retval  0   No error
 * @retval -1   Unable to open the board via index
 * @retval -2   Error when calling driver's IOCTL
 */
_INT_ i_PCIe1516_GetBoardInformation(IN  BYTE b_BoardIndex,
                                     IN  DWORD dw_IdentifierStringSize,
                                     OUT CHAR  *pc_Identifier,
                                     OUT DWORD *pdw_UINumber,
                                     OUT DWORD *pdw_DeviceNumber,
                                     OUT DWORD *pdw_BusNumber,
                                     OUT DWORD *pdw_BaseAddress0,
                                     OUT DWORD *pdw_BaseAddress1,
                                     OUT DWORD *pdw_BaseAddress2,
                                     OUT DWORD *pdw_BaseAddress3,
                                     OUT BYTE  *pb_Interrupt);


/* i_PCIe1516_OpenBoardViaIndex */
/**
 * Opens the board with the specified index. A handle is returned to the \n
 * user which allows driver functions to be used. \n
 *
 * @param[in]   b_BoardIndex Index of the board to open
 * @param[out]  ph_DeviceHandle Handle of the selected xPCIe1516 board
 * @retval  0   No error
 * @retval -1   Unable to get the number of available boards
 * @retval -2   Wrong device index parameter, the parameter is too high
 * @retval -3   Error while getting the device's class
 * @retval -4   Error while getting informations about the device
 * @retval -5   Memory allocation error
 * @retval -6   Get device interface detail error
 * @retval -7   Error while creating communication handle
 * @retval -8   Error in the initialization callback function
 */
_INT_ i_PCIe1516_OpenBoardViaIndex(IN BYTE b_BoardIndex, OUT HANDLE *ph_DeviceHandle);


/* i_PCIe1516_OpenBoardViaIdentifier */
/**
 * Opens the board with the specified identifier. A handle is returned to the \n
 * user which allows driver functions to be used. \n
 *
 * @param[in]   pc_Identifier Identifier of the board to open
 * @param[out]  ph_DeviceHandle Handle of the xPCIe1516 board
 * @retval  0   No Error
 * @retval -1   Unable to get the number of available boards
 * @retval -2   Unable to get the board identifier
 * @retval -3   Unable to open the board
 * @retval -4   Identifier not found
 */
_INT_ i_PCIe1516_OpenBoardViaIdentifier(IN CHAR pc_Identifier[], OUT HANDLE *ph_DeviceHandle);


/* i_PCIe1516_CloseBoard */
/**
 * Releases the handle to the board. Block the access to the board.
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @retval	0   No Error
 * @retval -1   The device handle parameter is wrong
 * @retval -2   Unable to close the device handle
 */
_INT_ i_PCIe1516_CloseBoard(HANDLE h_DeviceHandle);


/* i_PCIe1516_GetDLLVersion */
/**
 * Gets the version of the DLL.
 *
 * @param[out]  pdw_Version Version. For example: 0x01010910 -> Version 1.01, September 2010
 * @retval  0   No Error
 */
_INT_ i_PCIe1516_GetDLLVersion(OUT DWORD *pdw_Version);


/* i_PCIe1516_GetDeviceDriverVersion */
/**
 * Gets the version of the device driver.
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[out]  pdw_Version Version. For example: 0x01011211 -> Version 1.01, December 2011
 * @retval  0   No Error
 * @retval -1   Error while calling IOCTL function
 */
_INT_ i_PCIe1516_GetDeviceDriverVersion(IN HANDLE h_DeviceHandle, OUT DWORD *pdw_Version);


/* pc_PCIe1516_GetLastError */
/**
 * Gets a pointer to a string describing the last error that occurred.
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @returns a pointer to the error string
 */
const _PCHAR_ pc_PCIe1516_GetLastError(IN HANDLE h_DeviceHandle);


/* i_PCIe1516_SetBoardIntRoutine */
/**
 * Registers an interrupt callback function.
 * This callback function will be called each time the board generates an interruption. \n
 * The value of dw_InterruptSource will enable you to determine the source of the interruption:
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   v_FunctionName Address of the callback function
 *		\n	\b h_DeviceHandle: Handle of the board
 *		\n	\b b_FIFOOverflow: If uc_FIFOOverflow != 0, there are too many unprocessed interrupts in the kernel FIFO, and any new information is lost
 *		\n	\b dw_InterruptMask: Source of the interrupt
 *		\n	\b pw_Args: Values read during the interrupt. If DMA interrupt, this pointer will be set to NULL.
 *		\n	\b dw_ArgsCount: Number of values read during the interrupt
 *
 * @retval  0   No Error
 * @retval -1   The device handle parameter is wrong
 * @retval -2   An interrupt routine is already installed. Remove it with ResetBoardIntRoutine and retry
 * @retval -3   Error while creating kill event
 * @retval -4   Error while creating interrupt event
 * @retval -5   Error while creating interrupt thread
 * @retval -6   Error while changing the priority class of the thread
 * @retval -7   Error while changing the priority of the thread
 * @retval -8   Error while calling the IOCTL command
 * @retval -9   Error in the interrupt callback function
 */
_INT_ i_PCIe1516_SetBoardIntRoutine(IN HANDLE h_DeviceHandle,
                                    IN void (*v_FunctionName)(IN  HANDLE h_DeviceHandle,
                                                              IN  BYTE   b_FifoOverflow,
                                                              IN  DWORD  dw_InterruptSource,
                                                              IN  DWORD  dw_InterruptMask,
                                                              OUT WORD   *pw_Args,
                                                              IN  DWORD  dw_ArgsCount));


/* i_PCIe1516_ResetBoardIntRoutine */
/**
 * Deregisters the current interrupt callback function.
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @retval  0   No Error
 * @retval -1   The device handle parameter is wrong
 * @retval -2   No interrupt routine installed
 * @retval -3   Error in the reset interrupt callback function
 */
_INT_ i_PCIe1516_ResetBoardIntRoutine(IN HANDLE h_DeviceHandle);

/**		@}
 */

/**		\addtogroup DigitalInput xPCIe1516 Digital input functions
 * 		\ingroup PCIe1516
 *		@{
 */

/* i_PCIe1516_Read1DigitalInput */
/**
 * Reads 1 digital input of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Channel Channel to be read (0..7)
 * @param[out]  b_Value Status of the digital input
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The b_Channel parameter is wrong
 */
_INT_ i_PCIe1516_Read1DigitalInput(IN  HANDLE h_DeviceHandle,
                                   IN  BYTE b_Channel,
                                   OUT BYTE *b_Value);


/* i_PCIe1516_Read4DigitalInputs */
/**
 * Reads 4 digital inputs of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Port Port to be read. One port includes 4 channels (0..1)
 * @param[out]  b_Value Status of the digital inputs
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The b_Port parameter is wrong
 */
_INT_ i_PCIe1516_Read4DigitalInputs(IN  HANDLE h_DeviceHandle,
                                    IN  BYTE b_Port,
                                    OUT BYTE *b_Value);


/* i_PCIe1516_Read8DigitalInputs */
/**
 * Reads 8 digital inputs of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[out]  b_Value Status of the digital inputs
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -100 An error occurred while calling the IOCTL function
 */
_INT_ i_PCIe1516_Read8DigitalInputs(IN  HANDLE h_DeviceHandle,
                                    OUT BYTE *b_Value);

/**		@}
 */

/**		\addtogroup DigitalOutput xPCIe1516 Digital output functions
 * 		\ingroup PCIe1516
 *		@{
 */

/* i_PCIe1516_SetDigitalOutputMemoryOn */
/**
 * Activates the digital output memory of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 */
_INT_ i_PCIe1516_SetDigitalOutputMemoryOn(IN  HANDLE h_DeviceHandle);


/* i_PCIe1516_SetDigitalOutputMemoryOff */
/**
 * Desactivates the digital output memory of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 */
_INT_ i_PCIe1516_SetDigitalOutputMemoryOff(IN  HANDLE h_DeviceHandle);


/* i_PCIe1516_Set1DigitalOutputOn */
/**
 * Sets a digital output of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Channel Digital output to be set (0..7)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The b_Channel parameter is wrong
 */
_INT_ i_PCIe1516_Set1DigitalOutputOn(IN  HANDLE h_DeviceHandle,
                                     IN  BYTE b_Channel);


/* i_PCIe1516_Set1DigitalOutputOff */
/**
 * Resets a digital output of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Channel Digital output to be reset (0..7)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The b_Channel parameter is wrong
 * @retval -3   Can't set off a digital output while the output memory is off
 */
_INT_ i_PCIe1516_Set1DigitalOutputOff(IN  HANDLE h_DeviceHandle,
                                      IN  BYTE b_Channel);


/* i_PCIe1516_Set4DigitalOutputsOn */
/**
 * Sets several digital outputs of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Port Port on which digital outputs have to be set (0..1)
 * @param[in]   b_Mask Digital output mask value to set (0..15)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The b_Port parameter is wrong
 * @retval -3   The b_Mask parameter is wrong
 */
_INT_ i_PCIe1516_Set4DigitalOutputsOn(IN  HANDLE h_DeviceHandle,
                                      IN  BYTE b_Port,
                                      IN  BYTE b_Mask);


/* i_PCIe1516_Set4DigitalOutputsOff */
/**
 * Resets several digital outputs of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Port Port on which digital outputs have to be reset (0..1)
 * @param[in]   b_Mask Digital output mask value to reset (0..15)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The b_Port parameter is wrong
 * @retval -3   The b_Mask parameter is wrong
 * @retval -4   Can't set off a digital output while the output memorx os off
 */
_INT_ i_PCIe1516_Set4DigitalOutputsOff(IN  HANDLE h_DeviceHandle,
                                       IN  BYTE b_Port,
                                       IN  BYTE b_Mask);


/* i_PCIe1516_Set8DigitalOutputsOn */
/**
 * Sets several digital outputs of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Mask Digital output mask value to set
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 */
_INT_ i_PCIe1516_Set8DigitalOutputsOn(IN  HANDLE h_DeviceHandle,
                                      IN  BYTE b_Mask);


/* i_PCIe1516_Set8DigitalOutputsOff */
/**
 * Resets several digital outputs of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Mask Digital output mask value to reset
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   Can't set off a digital output while the digital output memory is off
 */
_INT_ i_PCIe1516_Set8DigitalOutputsOff(IN  HANDLE h_DeviceHandle,
                                       IN  BYTE b_Mask);


/* i_PCIe1516_SetAllDigitalOutputs */
/**
 * Sets / resets several digital outputs of the board without using the output memory
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Mask Digital output mask value to set / reset
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -100 An error occurred while calling the IOCTL function
 */
_INT_ i_PCIe1516_SetAllDigitalOutputs(IN  HANDLE h_DeviceHandle,
                                      IN  BYTE b_Mask);


/* i_PCIe1516_Get1DigitalOutputStatus */
/**
 * Reads 1 digital output of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Channel Channel to be read (0..7)
 * @param[out]  b_Status Status of the digital output (0: off, 1: on)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The b_Channel parameter is wrong
 */
_INT_ i_PCIe1516_Get1DigitalOutputStatus(IN  HANDLE h_DeviceHandle,
                                         IN  BYTE b_Channel,
                                         OUT BYTE *b_Status);


/* i_PCIe1516_Get4DigitalOutputStatus */
/**
 * Reads 4 digital outputs of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   b_Port Port on which digital outputs have to be read (0..1)
 * @param[out]  b_Status Status of the digital outputs (0: off, 1: on)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The b_Port parameter is wrong
 */
_INT_ i_PCIe1516_Get4DigitalOutputStatus(IN  HANDLE h_DeviceHandle,
                                         IN  BYTE b_Port,
                                         OUT BYTE *b_Status);


/* i_PCIe1516_Get8DigitalOutputsStatus */
/**
 * Read the 8 digital outputs status of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[out]  b_Status Status of the digital outputs (0: off, 1: on)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -100 An error occurred while calling the IOCTL function
 */
_INT_ i_PCIe1516_Get8DigitalOutputsStatus(IN  HANDLE h_DeviceHandle,
                                          OUT BYTE *b_Status);

/**		@}
 */

/**		\addtogroup Watchdog xPCIe1516 Watchdog functions
 * 		\ingroup PCIe1516
 *		@{
 */

/* i_PCIe1516_InitAndStartWatchdog */
/**
 * Initializes and starts the watchdog of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[in]   w_ReloadValue Watchdog reload value (1..0xFFF)
 * @param[in]   b_TimeBase Time base of the watchdog (0 for microseconds, 1 for milliseconds and 2 for seconds) (0..2)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -2   The w_ReloadValue parameter is wrong
 * @retval -3   The b_TimeBase parameter is wrong
 * @retval -100 An error occurred while calling the IOCTL function
 */
_INT_ i_PCIe1516_InitAndStartWatchdog(IN  HANDLE h_DeviceHandle,
                                      IN  WORD w_ReloadValue,
                                      IN  BYTE b_TimeBase);


/* i_PCIe1516_ReadWatchdogValue */
/**
 * Reads the value of the watchdog of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[out]  w_Value Current value of the watchdog
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -100 An error occurred while calling the IOCTL function
 */
_INT_ i_PCIe1516_ReadWatchdogValue(IN  HANDLE h_DeviceHandle,
                                   OUT WORD *w_Value);


/* i_PCIe1516_ReadWatchdogStatus */
/**
 * Reads the status of the watchdog of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @param[out]  b_Status Current status of the watchdog (0: disabled, 1: enabled)
 * @param[out]  b_SoftwareTriggerStatus Current status of the software trigger (0: no trigger occured, 1: a trigger occured)
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -100 An error occurred while calling the IOCTL function
 */
_INT_ i_PCIe1516_ReadWatchdogStatus(IN  HANDLE h_DeviceHandle,
                                    OUT BYTE *b_Status,
                                    OUT BYTE *b_SoftwareTriggerStatus);


/* i_PCIe1516_TriggerWatchdog */
/**
 * Triggers the watchdog
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -100 An error occurred while calling the IOCTL function
 */
_INT_ i_PCIe1516_TriggerWatchdog(IN  HANDLE h_DeviceHandle);


/* i_PCIe1516_StopAndReleaseWatchdog */
/**
 * Stops and releases the watchdog of the board
 *
 * @param[in]   h_DeviceHandle Handle of the board
 * @retval  0   No error
 * @retval -1   The h_DeviceHandle parameter is wrong
 * @retval -100 An error occurred while calling the IOCTL function
 */
_INT_ i_PCIe1516_StopAndReleaseWatchdog(IN  HANDLE h_DeviceHandle);

/**		@}
 */

//##protect##"UserHeaderEnd"
//##protect##"UserHeaderEnd"
/**	@}
 */

#ifdef __cplusplus
}
#endif
