//##protect##"FileHeader"
/** @file Watchdog.c
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 03.12.2012
 *  @date    $LastChangedDate: 2012-12-07 10:36:45 +0100 (Fr, 07. Dez 2012) $
 *  @version $LastChangedRevision: 3640 $
 *
 *  @par DESCRIPTION
 *  This sample show you how to use the watchdog of the board 
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

#include "StdAfx.h"

//##protect##"Watchdog_Head"
//##protect##"Watchdog_Head"

int _tmain(int argc, _TCHAR *argv[])
{
	INT    i_ReturnValue = 0;
	HANDLE h_BoardHandle = NULL;
//##protect##"Watchdog_VariablesDeclaration"
	BYTE   b_TimeBase = 0;
	WORD   w_ReloadValue = 0;
	BYTE   b_Channel = 0;
	WORD   w_Value = 0;
	BYTE   b_Status = 0;
	BYTE   b_SoftwareTriggerStatus = 0;
	BYTE   b_Stop = 0;
//##protect##"Watchdog_VariablesDeclaration"

	UNREFERENCED_PARAMETER(argc);
	UNREFERENCED_PARAMETER(argv);

	printf("/****************************************************************************\\\n"
	       "|*                             Watchdog sample                              *|\n"
	       "|****************************************************************************|\n"
	       "|* This sample show you how to use the watchdog of the board                *|\n"
	       "\\****************************************************************************/\n\n");

//##protect##"Watchdog_Start"
//##protect##"Watchdog_Start"

	i_ReturnValue = i_Utils_OpenBoard(&h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_Utils_OpenBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"Watchdog_Body"
	b_TimeBase = (BYTE)ll_Utils_ReadInteger(0, 2, "Select a time base (0 for us, 1 for ms, 2 for s):");
	w_ReloadValue = (WORD)ll_Utils_ReadInteger(1, 4095, "Enter a reload value (from 0 to 4095):");

	printf("\n****   Press 'T' to do a software trigger,         ****\n");
	printf("****   'S' to set a digital output on/off,         ****\n");
	printf("****   and ESC to stop the sample.                 ****\n");
	printf("****   The first trigger will start the watchdog.  ****\n\n");

	i_ReturnValue = i_PCIe1516_InitAndStartWatchdog(h_BoardHandle, w_ReloadValue, b_TimeBase);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
		i_PCIe1516_CloseBoard(h_BoardHandle);
		_getch();
		return i_ReturnValue;
	}

	while (!b_Stop)
	{
		i_ReturnValue = i_PCIe1516_ReadWatchdogValue(h_BoardHandle, &w_Value);

		if (i_ReturnValue != 0)
		{
			fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
			i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return i_ReturnValue;
		}

		printf("\rTimerValue = %ld        ", w_Value);
		i_ReturnValue = i_PCIe1516_ReadWatchdogStatus(h_BoardHandle, &b_Status, &b_SoftwareTriggerStatus);
		if (i_ReturnValue != 0)
		{
			fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
			i_PCIe1516_CloseBoard(h_BoardHandle);
			_getch();
			return i_ReturnValue;
		}

		if (_kbhit())
		{
			switch (_getch())
			{
				case 27:
					b_Stop = 1;
					break;
				case 'S':
				case 's':
				{
					/* Compute the value to set the next output on */
					if (b_Channel < 9)
					{
						if (b_Channel == 8)
							b_Channel = 0;

					i_ReturnValue = i_PCIe1516_Set8DigitalOutputsOn(h_BoardHandle, (1 << b_Channel));
					if (i_ReturnValue != 0)
					{
						fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
						i_PCIe1516_CloseBoard(h_BoardHandle);
						_getch();
						return i_ReturnValue;
					}

					printf("\nChannel %d set on. \n\n", b_Channel);

					b_Channel++;
					}
				}
				break;

				case 'T':
				case 't':
				{
					i_ReturnValue = i_PCIe1516_TriggerWatchdog(h_BoardHandle);
					if (i_ReturnValue != 0)
					{
						fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
						i_PCIe1516_CloseBoard(h_BoardHandle);
						_getch();
						return i_ReturnValue;
					}
				}
				break;

				default:
					break;
			}
		}
	}

	i_ReturnValue = i_PCIe1516_StopAndReleaseWatchdog(h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "%s\n", pc_PCIe1516_GetLastError(h_BoardHandle));
		i_PCIe1516_CloseBoard(h_BoardHandle);
		_getch();
		return i_ReturnValue;
	}
//##protect##"Watchdog_Body"

	i_ReturnValue = i_PCIe1516_CloseBoard(h_BoardHandle);
	if (i_ReturnValue != 0)
	{
		fprintf(stderr, "i_PCIe1516_CloseBoard failed: %d\n", i_ReturnValue);
		_getch();
		return i_ReturnValue;
	}

//##protect##"Watchdog_End"
//##protect##"Watchdog_End"

	printf("\nPress any key to exit the sample...\n");
	_getch();
	return i_ReturnValue;
}
