//##protect##"FileHeader"
/** @file DllImport.cs
 *
 *  @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
 *  @date    Creation: 27.11.2012
 *  @date    $LastChangedDate: 2012-12-07 10:36:45 +0100 (Fr, 07. Dez 2012) $
 *  @version $LastChangedRevision: 3640 $
 *
 *  @par DESCRIPTION
 *  PCIe1516.dll imports
 *
 *  @par LICENCE
 *  @verbatim
 *  Copyright (C) 2009 - 2012 ADDI-DATA GmbH
 *
 *  ADDI-DATA GmbH
 *  Airpark Business Center
 *  Airport Boulevard B210
 *  77836 Rheinmnster
 *  Germany
 *  Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
 *  http://www.addi-data-com  |  info@addi-data.com
 *  @endverbatim
 **/
//##protect##"FileHeader"

using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;

namespace PCIe1516_NET
{
    /// <summary>
    /// Contains the prototypes of the DLL functions
    /// </summary>
    public class DllImport
    {
        /// <summary>
        /// Definition of the user interruption function prototype
        /// </summary>
        [UnmanagedFunctionPointer(CallingConvention.Cdecl)]
        public delegate void InterruptFunctionEventHandler(IntPtr handle, Byte overflow, UInt32 source, UInt32 mask, IntPtr args, UInt32 argsSize);

#region "Generic"
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_GetNumberOfBoards(out Byte pb_NbrOfBoards);
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_GetBoardInformation(Byte b_BoardIndex, UInt32 dw_IdentifierStringSize, out Byte[] pc_Identifier, out UInt32 pdw_UINumber, out UInt32 pdw_DeviceNumber, out UInt32 pdw_BusNumber, out UInt32 pdw_BaseAddress0, out UInt32 pdw_BaseAddress1, out UInt32 pdw_BaseAddress2, out UInt32 pdw_BaseAddress3, out Byte pb_Interrupt);
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_OpenBoardViaIndex(Byte b_BoardIndex, out IntPtr ph_DeviceHandle);
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_OpenBoardViaIdentifier(out Byte[] pc_Identifier, out IntPtr ph_DeviceHandle);
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_CloseBoard(IntPtr h_DeviceHandle);
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_GetDLLVersion(out Int32 pdw_Version);
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_GetDeviceDriverVersion(IntPtr h_DeviceHandle, out Int32 pdw_Version);
		[DllImport("PCIe1516.dll")]
		public static extern IntPtr pc_PCIe1516_GetLastError(IntPtr h_DeviceHandle);
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_SetBoardIntRoutine(IntPtr h_DeviceHandle, [MarshalAs(UnmanagedType.FunctionPtr)] InterruptFunctionEventHandler interruptFunction);
		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_ResetBoardIntRoutine(IntPtr h_DeviceHandle);
#endregion

#region "PCIe1516"

#endregion
#region "DigitalInput"

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Read1DigitalInput(IntPtr deviceHandle, Byte channel, out Byte value);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Read4DigitalInputs(IntPtr deviceHandle, Byte port, out Byte value);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Read8DigitalInputs(IntPtr deviceHandle, out Byte value);

#endregion
#region "DigitalOutput"

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_SetDigitalOutputMemoryOn(IntPtr deviceHandle);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_SetDigitalOutputMemoryOff(IntPtr deviceHandle);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Set1DigitalOutputOn(IntPtr deviceHandle, Byte channel);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Set1DigitalOutputOff(IntPtr deviceHandle, Byte channel);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Set4DigitalOutputsOn(IntPtr deviceHandle, Byte port, Byte mask);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Set4DigitalOutputsOff(IntPtr deviceHandle, Byte port, Byte mask);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Set8DigitalOutputsOn(IntPtr deviceHandle, Byte mask);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Set8DigitalOutputsOff(IntPtr deviceHandle, Byte mask);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_SetAllDigitalOutputs(IntPtr deviceHandle, Byte mask);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Get1DigitalOutputStatus(IntPtr deviceHandle, Byte channel, out Byte status);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Get4DigitalOutputStatus(IntPtr deviceHandle, Byte port, out Byte status);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_Get8DigitalOutputsStatus(IntPtr deviceHandle, out Byte status);

#endregion
#region "Watchdog"

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_InitAndStartWatchdog(IntPtr deviceHandle, UInt16 reloadValue, Byte timeBase);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_ReadWatchdogValue(IntPtr deviceHandle, out UInt16 value);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_ReadWatchdogStatus(IntPtr deviceHandle, out Byte status, out Byte softwareTriggerStatus);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_TriggerWatchdog(IntPtr deviceHandle);

		[DllImport("PCIe1516.dll")]
		public static extern short i_PCIe1516_StopAndReleaseWatchdog(IntPtr deviceHandle);

#endregion
#region "Misc"
//##protect##"DllImportMisc"
//##protect##"DllImportMisc"
#endregion
    }
}
