using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Set8DigitalOutputs
{
    public partial class Set8DigitalOutputs : Form
    {
        /// <summary>
        /// Board object
        /// </summary>
        private PCIe1516_NET.PCIe1516 board;

        /// <summary>
        /// Useful array to access all the checkboxes
        /// </summary>
        private CheckBox[] outputCheckBoxes;

        /// <summary>
        /// Enables to lock the events
        /// </summary>
        private bool locked;

        /// <summary>
        /// Constructor of the form
        /// </summary>
        public Set8DigitalOutputs()
        {
            InitializeComponent();

            // Construct the useful array
            this.outputCheckBoxes = new CheckBox[8];
            this.outputCheckBoxes[0] = this.output0CheckBox;
            this.outputCheckBoxes[1] = this.output1CheckBox;
            this.outputCheckBoxes[2] = this.output2CheckBox;
            this.outputCheckBoxes[3] = this.output3CheckBox;
            this.outputCheckBoxes[4] = this.output4CheckBox;
            this.outputCheckBoxes[5] = this.output5CheckBox;
            this.outputCheckBoxes[6] = this.output6CheckBox;
            this.outputCheckBoxes[7] = this.output7CheckBox;
        }

        /// <summary>
        /// Occurs the first time the form loads
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Set8DigitalOutputs_Load(object sender, EventArgs e)
        {
            int returnValue = 0;

            // Construct the board object
            this.board = PCIe1516_NET.PCIe1516.OpenBoard(0);

            // Check the result
            if (this.board == null)
            {
                MessageBox.Show("Error while opening board 0");
                this.Close();
                return;
            }

            // Set the output memory to off
            if ((returnValue = board.SetDigitalOutputMemoryOff()) != 0)
            {
                MessageBox.Show("Error while setting output memory to off : " + returnValue);
                this.Close();
                return;
            }

            // Update values of the outputs
            UpdateOutputValues();
        }

        /// <summary>
        /// Update the output values
        /// </summary>
        private void UpdateOutputValues()
        {
            byte outputStatus = 0;
            int returnValue = 0;

            // Get the current status of the outputs
            if ((returnValue = board.Get8DigitalOutputsStatus(out outputStatus)) != 0)
            {
                MessageBox.Show("Error while getting status of the 8 digital outputs : " + returnValue);
                return;
            }

            // Lock
            locked = true;

            // Change the status of the checkboxes
            for (int i = 0; i < 8; i++)
            {
                if ( (uint)(outputStatus & (1 << i)) == (uint)(1 << i))
                {
                    this.outputCheckBoxes[i].Checked = true;
                }
                else
                {
                    this.outputCheckBoxes[i].Checked = false;
                }
            }

            // Unlock
            locked = false;
        }

        /// <summary>
        /// Change the checkbox value
        /// </summary>
        /// <param name="index"></param>
        private void CheckBoxChanged(int index)
        {
            int returnValue = 0;

            // Changement due to update value function ?
            if (locked == true)
            {
                return;
            }

            if (this.outputCheckBoxes[index].Checked == true)
            {
                // Set to on
                if ((returnValue = board.Set8DigitalOutputsOn((byte)(1 << index))) != 0)
                {
                    MessageBox.Show("Error while setting 8 digital outputs to on : " + returnValue);
                }
            }
            else
            {
                // Set to off

                // Check the status of the output memory
                if (outputMemoryCheckBox.Checked == true)
                {
                    if ((returnValue = board.Set8DigitalOutputsOff((byte)(1 << index))) != 0)
                    {
                        MessageBox.Show("Error while setting 8 digital outputs to off : " + returnValue);
                    }
                }
            }

            // Update values
            this.UpdateOutputValues();
        }

        private void output0CheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.CheckBoxChanged(0);
        }

        private void output1CheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.CheckBoxChanged(1);
        }

        private void output2CheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.CheckBoxChanged(2);
        }

        private void output3CheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.CheckBoxChanged(3);
        }

        private void output4CheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.CheckBoxChanged(4);
        }

        private void output5CheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.CheckBoxChanged(5);
        }

        private void output6CheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.CheckBoxChanged(6);
        }

        private void output7CheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.CheckBoxChanged(7);
        }

        /// <summary>
        /// Change the state of the output memory
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void outputMemoryCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            int returnValue = 0;

            if (outputMemoryCheckBox.Checked == true)
            {
                // Set to on
                if ((returnValue = board.SetDigitalOutputMemoryOn()) != 0)
                {
                    MessageBox.Show("Error while setting digital output memory to on : " + returnValue);
                }
            }
            else
            {
                // Set to off
                if ((returnValue = board.SetDigitalOutputMemoryOff()) != 0)
                {
                    MessageBox.Show("Error while setting digital output memory to off : " + returnValue);
                }
            }
        }
    }
}