%##protect##"FileHeader"
%%
% @file Read1DigitalInput.m
% 
% @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
% @date    Creation: 11.02.2013
% @date    $LastChangedDate: 2013-02-18 15:44:16 +0100 (Mo, 18. Feb 2013) $
% @version $LastChangedRevision: 3873 $
% 
% @par DESCRIPTION
% Reads one digital input of the board 
% 
% @par LICENCE
% @verbatim
% Copyright (C) 2009 - 2013 ADDI-DATA GmbH
% 
% ADDI-DATA GmbH
% Airpark Business Center
% Airport Boulevard B210
% 77836 Rheinmnster
% Germany
% Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
% http://www.addi-data-com  |  info@addi-data.com
% @endverbatim
%%
%##protect##"FileHeader"

addpath('../MEX');

clc;                            % Clears the command window

%##protect##"Read1DigitalInput_VariablesDeclaration"
inputValues = zeros(1, 10000, 'uint16');
time = zeros(1, 10000);
%##protect##"Read1DigitalInput_VariablesDeclaration"


disp('**************************************************************************************');
disp('***                            Read1DigitalInput sample                            ***');
disp('**************************************************************************************');
disp('***    Reads one digital input of the board                                        ***');
disp('**************************************************************************************');

disp (' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');
channel = input('Which channel do you want to use (0 to 7)? ');
while ((channel < 0) && (channel > 7))
    channel = input('Which channel do you want to use (0 to 7)? ');
end
%##protect##"Read1DigitalInput_AcquisitionInputs"
%##protect##"Read1DigitalInput_AcquisitionInputs"

disp (' ');

%##protect##"Read1DigitalInput_Start"
%##protect##"Read1DigitalInput_Start"

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

%##protect##"Read1DigitalInput_Body"
disp('Acquisition in progress...');
disp('Please wait');

time(1, 1) = 0;
nb = 1;
for i = 1:1:10000
    t1 = clock;

    % Reads the values of the digital input
    [returnError, inputValues(i)] = i_PCIe1516_mexRead1DigitalInput(handle, channel);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
    
    tic;                        % Wait for 1 ms (the pause function doesn't allow us to wait less than 1 sec)
    while toc < 0.001
    end

    t2 = clock;
    if (i <= 2)
        time(1, i) = etime(t2, t1);
    else
        time(1, i) = time(i-1) + etime(t2, t1);
    end
end

% Displays the values of the digital input
plot(time, inputValues);  % Display the selected input
title(['Value of the input ', num2str(channel)], 'Fontsize', 10, 'Color', 'blue');
ylim([-0.25 1.25]);
ylabel(['Channel ', num2str(channel)]);
%##protect##"Read1DigitalInput_Body"

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
