%##protect##"FileHeader"
%%
% @file Read4DigitalInputs.m
% 
% @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
% @date    Creation: 11.02.2013
% @date    $LastChangedDate: 2013-02-18 15:44:16 +0100 (Mo, 18. Feb 2013) $
% @version $LastChangedRevision: 3873 $
% 
% @par DESCRIPTION
% Reads four digital inputs of the board 
% 
% @par LICENCE
% @verbatim
% Copyright (C) 2009 - 2013 ADDI-DATA GmbH
% 
% ADDI-DATA GmbH
% Airpark Business Center
% Airport Boulevard B210
% 77836 Rheinmnster
% Germany
% Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
% http://www.addi-data-com  |  info@addi-data.com
% @endverbatim
%%
%##protect##"FileHeader"

addpath('../MEX');

clc;                            % Clears the command window

%##protect##"Read4DigitalInputs_VariablesDeclaration"
tempValues = zeros(1, 10000, 'uint16');
inputsValues = zeros(4, 10000, 'uint16');
time = zeros(1, 10000);
%##protect##"Read4DigitalInputs_VariablesDeclaration"


disp('**************************************************************************************');
disp('***                           Read4DigitalInputs sample                            ***');
disp('**************************************************************************************');
disp('***    Reads four digital inputs of the board                                      ***');
disp('**************************************************************************************');

disp (' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');
%##protect##"Read4DigitalInputs_AcquisitionInputs"
port = input('Which port do you want to read (0 to 1)? ');
while ((port < 0) && (port > 1))
	port = input('Which port do you want to read (0 to 1)? ');
end
%##protect##"Read4DigitalInputs_AcquisitionInputs"

disp (' ');

%##protect##"Read4DigitalInputs_Start"
%##protect##"Read4DigitalInputs_Start"

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

%##protect##"Read4DigitalInputs_Body"
disp('Acquisition in progress...');
disp('Please wait');

time(1, 1) = 0;
nb = 1;
for i = 1:1:10000
    t1 = clock;

    % Reads the values of the digital inputs of the selected port
    [returnError, tempValues(i)] = i_PCIe1516_mexRead4DigitalInputs(handle, port);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
    
    for j = 1:1:4
        % Separates the values of each channel
        x = bitand(tempValues(i), bitshift(1,(j-1)));
        if (x == 0)
            inputsValues(j, i) = 0;
        else
            inputsValues(j, i) = 1;
        end
    end

    tic;                        % Wait for 1 ms (the pause function doesn't allow us to wait less than 1 sec)
    while toc < 0.001
    end

    t2 = clock;
    if (i <= 2)
        time(1, i) = etime(t2, t1);
    else
        time(1, i) = time(i-1) + etime(t2, t1);
    end
end

% Displays the values of the 4 selected digital inputs on separated figures
for j = 1:1:3
    if (port == 0)
        i = (j-1);
    else
        i = j + 3;
    end
    subplot(4,1,j);
    plot(time, inputsValues(j, :));  % Display the input x
    if (j == 1)
        title(['Values of the four digital inputs of the selected port ', num2str(port)], 'Fontsize', 10, 'Color', 'blue');
    end
    set(gca, 'XTick', []);
    ylim([-0.25 1.25]);
    ylabel(['Channel ', num2str(i)]);
end
if (port == 0)
    i = 3;
else
    i = 7;
end
subplot(4,1,4);
plot(time, inputsValues(4, :));      % Display the input 3 separatelly
xlabel('Time in secondes');          % to add an X axe at the end
ylim([-0.25 1.25]);
ylabel(['Channel ', num2str(i)]);
%##protect##"Read4DigitalInputs_Body"

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
