%##protect##"FileHeader"
%%
% @file Read8DigitalInputs.m
% 
% @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
% @date    Creation: 11.02.2013
% @date    $LastChangedDate: 2013-02-18 15:44:16 +0100 (Mo, 18. Feb 2013) $
% @version $LastChangedRevision: 3873 $
% 
% @par DESCRIPTION
% Reads eight digital inputs of the board 
% 
% @par LICENCE
% @verbatim
% Copyright (C) 2009 - 2013 ADDI-DATA GmbH
% 
% ADDI-DATA GmbH
% Airpark Business Center
% Airport Boulevard B210
% 77836 Rheinmnster
% Germany
% Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
% http://www.addi-data-com  |  info@addi-data.com
% @endverbatim
%%
%##protect##"FileHeader"

addpath('../MEX');

clc;                            % Clears the command window

%##protect##"Read8DigitalInputs_VariablesDeclaration"
tempValues = zeros(1, 10000, 'uint16');
inputsValues = zeros(8, 10000, 'uint16');
time = zeros(1, 10000);
labelY = ['0', '1', '2', '3', '4', '5', '6', '7'];
%##protect##"Read8DigitalInputs_VariablesDeclaration"


disp('**************************************************************************************');
disp('***                           Read8DigitalInputs sample                            ***');
disp('**************************************************************************************');
disp('***    Reads eight digital inputs of the board                                     ***');
disp('**************************************************************************************');

disp (' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');
%##protect##"Read8DigitalInputs_AcquisitionInputs"
%##protect##"Read8DigitalInputs_AcquisitionInputs"

disp (' ');

%##protect##"Read8DigitalInputs_Start"
%##protect##"Read8DigitalInputs_Start"

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

%##protect##"Read8DigitalInputs_Body"
disp('Acquisition in progress...');
disp('Please wait');

time(1, 1) = 0;
nb = 1;
for i = 1:1:10000
    t1 = clock;

    % Reads the values of the digital inputs
    [returnError, tempValues(i)] = i_PCIe1516_mexRead8DigitalInputs(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
    
    for j = 1:1:8
        % Separates the values of each channel
        x = bitand(tempValues(i), bitshift(1,(j-1)));
        if (x == 0)
            inputsValues(j, i) = 0;
        else
            inputsValues(j, i) = 1;
        end
    end

    tic;                        % Wait for 1 ms (the pause function doesn't allow us to wait less than 1 sec)
    while toc < 0.001
    end

    t2 = clock;
    if (i <= 2)
        time(1, i) = etime(t2, t1);
    else
        time(1, i) = time(i-1) + etime(t2, t1);
    end
end

% Displays the values of the 8 digital inputs on separated figures
for j = 1:1:7
    subplot(8,1,j);
    plot(time, inputsValues(j, :));  % Display the input x
    if (j == 1)
        title('Values of the eight digital inputs of the PCIe1516 board', 'Fontsize', 10, 'Color', 'blue');
    end
    set(gca, 'XTick', []);
    ylim([-0.25 1.25]);
    ylabel(labelY(j));
end
subplot(8,1,8);
plot(time, inputsValues(8, :));       % Display the input 7 separatelly
xlabel('Time in secondes');          % to add an X axe at the end
ylim([-0.25 1.25]);
ylabel(labelY(8));
%##protect##"Read8DigitalInputs_Body"

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
