%##protect##"FileHeader"
%%
% @file Get1DigitalOutputStatus.m
% 
% @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
% @date    Creation: 11.02.2013
% @date    $LastChangedDate: 2013-02-18 15:44:16 +0100 (Mo, 18. Feb 2013) $
% @version $LastChangedRevision: 3873 $
% 
% @par DESCRIPTION
% Gets the status of one digital output 
% 
% @par LICENCE
% @verbatim
% Copyright (C) 2009 - 2013 ADDI-DATA GmbH
% 
% ADDI-DATA GmbH
% Airpark Business Center
% Airport Boulevard B210
% 77836 Rheinmnster
% Germany
% Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
% http://www.addi-data-com  |  info@addi-data.com
% @endverbatim
%%
%##protect##"FileHeader"

addpath('../MEX');

clc;                            % Clears the command window

%##protect##"Get1DigitalOutputStatus_VariablesDeclaration"
answer = 1;
%##protect##"Get1DigitalOutputStatus_VariablesDeclaration"


disp('**************************************************************************************');
disp('***                         Get1DigitalOutputStatus sample                         ***');
disp('**************************************************************************************');
disp('***    Gets the status of one digital output                                       ***');
disp('**************************************************************************************');

disp (' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');
%##protect##"Get1DigitalOutputStatus_AcquisitionInputs"
memoryFlag = input('Do you want to use the digital output memory (0: no, 1: yes)? ');
while ((memoryFlag < 0) || (memoryFlag > 1))
    memoryFlag = input('Do you want to use the digital output memory (0: no, 1: yes)? ');
end
%##protect##"Get1DigitalOutputStatus_AcquisitionInputs"

disp (' ');

%##protect##"Get1DigitalOutputStatus_Start"
%##protect##"Get1DigitalOutputStatus_Start"

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

%##protect##"Get1DigitalOutputStatus_Body"
% Sets all the digital outputs off
[returnError] = i_PCIe1516_mexSetAllDigitalOutputs(handle, 0);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

% Set the digital output memory flag
if (memoryFlag == 0)
    [returnError] = i_PCIe1516_mexSetDigitalOutputMemoryOff(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end
else
    [returnError] = i_PCIe1516_mexSetDigitalOutputMemoryOn(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end
end

while (answer == 1)
    disp(' ');

    channel = input('Which channel do you want the status (0 to 7)? ');
    while ((channel < 0) || (channel > 7))
        channel = input('Which channel do you want the status (0 to 7)? ');
    end
    
	% Sets the digital output on
	[returnError] = i_PCIe1516_mexSet1DigitalOutputOn(handle, channel);
	if (returnError ~= 0)
		[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
		break;
	end
	
	toDisp = 'Channel %d set.\n';
	fprintf(toDisp, channel);
	
	% Gets the status of the selected channel
    [returnError, status] = i_PCIe1516_mexGet1DigitalOutputStatus(handle, channel);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
	
	toDisp = 'Status of the channel %d: 0x%x.\n';
	fprintf(toDisp, channel, status);
	
	pause(1);		% Wait for 1 sec
    if (memoryFlag == 1)
        % Sets the digital output off
        [returnError] = i_PCIe1516_mexSet1DigitalOutputOff(handle, channel);
        if (returnError ~= 0)
            [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
            break;
        end
    end
	
	toDisp = 'Channel %d reset.\n';
	fprintf(toDisp, channel);
	
	% Gets the status of the selected channel
    [returnError, status] = i_PCIe1516_mexGet1DigitalOutputStatus(handle, channel);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
	
	toDisp = 'Status of the channel %d: 0x%x.\n';
	fprintf(toDisp, channel, status);

	answer = input('Do you want to continue or stop the sample (0: stop, 1: continue)? ');
	while ((answer < 0) || (answer > 1))
		answer = input('Do you want to continue or stop the sample (0: stop, 1: continue)? ');
	end
end
%##protect##"Get1DigitalOutputStatus_Body"

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
