%##protect##"FileHeader"
%%
% @file Get8DigitalOutputsStatus.m
% 
% @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
% @date    Creation: 11.02.2013
% @date    $LastChangedDate: 2013-02-18 15:44:16 +0100 (Mo, 18. Feb 2013) $
% @version $LastChangedRevision: 3873 $
% 
% @par DESCRIPTION
% Gets the status of eight digital outputs 
% 
% @par LICENCE
% @verbatim
% Copyright (C) 2009 - 2013 ADDI-DATA GmbH
% 
% ADDI-DATA GmbH
% Airpark Business Center
% Airport Boulevard B210
% 77836 Rheinmnster
% Germany
% Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
% http://www.addi-data-com  |  info@addi-data.com
% @endverbatim
%%
%##protect##"FileHeader"

addpath('../MEX');

clc;                            % Clears the command window

%##protect##"Get8DigitalOutputsStatus_VariablesDeclaration"
tempValues = zeros(1, 8000, 'uint16');
outputsValues = zeros(8, 8000, 'uint16');
time = zeros(1, 8000);
labelY = ['0', '1', '2', '3', '4', '5', '6', '7'];
%##protect##"Get8DigitalOutputsStatus_VariablesDeclaration"


disp('**************************************************************************************');
disp('***                        Get8DigitalOutputsStatus sample                         ***');
disp('**************************************************************************************');
disp('***    Gets the status of eight digital outputs                                    ***');
disp('**************************************************************************************');

disp (' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');
%##protect##"Get8DigitalOutputsStatus_AcquisitionInputs"
memoryFlag = input('Do you want to use the digital output memory (0: no, 1: yes)? ');
while ((memoryFlag < 0) || (memoryFlag > 1))
    memoryFlag = input('Do you want to use the digital output memory (0: no, 1: yes)? ');
end
%##protect##"Get8DigitalOutputsStatus_AcquisitionInputs"

disp (' ');

%##protect##"Get8DigitalOutputsStatus_Start"
%##protect##"Get8DigitalOutputsStatus_Start"

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

%##protect##"Get8DigitalOutputsStatus_Body"
% Sets all the digital outputs off
[returnError] = i_PCIe1516_mexSetAllDigitalOutputs(handle, 0);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

% Set the digital output memory flag
if (memoryFlag == 0)
    [returnError] = i_PCIe1516_mexSetDigitalOutputMemoryOff(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end
else
    [returnError] = i_PCIe1516_mexSetDigitalOutputMemoryOn(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end
end

disp('Acquisition in progress...');
disp('Please wait');

time(1, 1) = 0;
nb = 1;
for j = 1:1:8
    % Sets the digital outputs on
    [returnError] = i_PCIe1516_mexSet8DigitalOutputsOn(handle, bitshift(1, (j-1)));
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
    
    for i = 1:1:500
        t1 = clock;
        % Acquisition of the status of the digital outputs
        [returnError, tempValues(nb)] = i_PCIe1516_mexGet8DigitalOutputsStatus(handle);
        if (returnError ~= 0)
            [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
            break;
        end
        
        for k = 1:1:8
            % Separates the values of each channel
            x = bitand(tempValues(nb), bitshift(1,(k-1)));
            if (x == 0)
                outputsValues(k, nb) = 0;
            else
                outputsValues(k, nb) = 1;
            end
        end

        tic;                        % Wait for 1 ms (the pause function doesn't allow us to wait less than 1 sec)
        while toc < 0.001
        end

        t2 = clock;
        if (nb <= 2)
            time(1, nb) = etime(t2, t1);
        else
            time(1, nb) = time(nb-1) + etime(t2, t1);
        end
        nb = nb + 1;
    end
end

if (memoryFlag == 1)
    for j = 1:1:8
        % Sets the digital outputs off
        [returnError] = i_PCIe1516_mexSet8DigitalOutputsOff(handle, bitshift(1, (j-1)));
        if (returnError ~= 0)
            [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
            break;
        end

        for i = 1:1:500
            t1 = clock;
            % Acquisition of the status of the digital outputs
            [returnError, tempValues(nb)] = i_PCIe1516_mexGet8DigitalOutputsStatus(handle);
            if (returnError ~= 0)
                [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
                break;
            end

        
            for k = 1:1:8
                % Separates the status of each channel
                x = bitand(tempValues(nb), bitshift(1,(k-1)));
                if (x == 0)
                    outputsValues(k, nb) = 0;
                else
                    outputsValues(k, nb) = 1;
                end
            end

            tic;                        % Wait for 1 ms (the pause function doesn't allow us to wait less than 1 sec)
                while toc < 0.001
            end

            t2 = clock;
            time(1, nb) = time(nb-1) + etime(t2, t1);
            nb = nb + 1;
        end
    end
end

if (memoryFlag == 0)
    % Displays the values of the 8 digital inputs on separated figures
    for j = 1:1:7
        subplot(8,1,j);
        plot(time(1, 1:4000), outputsValues(j, 1:4000), 'b');   % Display the output x
        if (j == 1)
            title('Status of the eight digital outputs of the PCIe1516 board', 'Fontsize', 10, 'Color', 'blue');
        end
        set(gca, 'XTick', []);
        ylim([-0.25 1.25]);
        ylabel(labelY(j));
    end
    subplot(8,1,8);
    plot(time(1, 1:4000), outputsValues(8, 1:4000), 'b');       % Display the output 7
    xlabel('Time in secondes');                                 % to add an X axe at the end
    ylim([-0.25 1.25]);
    ylabel(labelY(8));
else
    % Displays the values of the 8 digital inputs on separated figures
    for j = 1:1:7
        subplot(8,1,j);
        plot(time(1, 1:8000), outputsValues(j, 1:8000), 'b');   % Display the output x
        if (j == 1)
            title('Status of the eight digital outputs of the PCIe1516 board', 'Fontsize', 10, 'Color', 'blue');
        end
        set(gca, 'XTick', []);
        ylim([-0.25 1.25]);
        ylabel(labelY(j));
    end
    subplot(8,1,8);
    plot(time(1, 1:8000), outputsValues(8, 1:8000), 'b');       % Display the output 7
    xlabel('Time in secondes');                                 % to add an X axe at the end
    ylim([-0.25 1.25]);
    ylabel(labelY(8));
end
%##protect##"Get8DigitalOutputsStatus_Body"

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
