%##protect##"FileHeader"
%%
% @file Set1DigitalOutput.m
% 
% @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
% @date    Creation: 11.02.2013
% @date    $LastChangedDate: 2013-02-18 15:44:16 +0100 (Mo, 18. Feb 2013) $
% @version $LastChangedRevision: 3873 $
% 
% @par DESCRIPTION
% Sets one digital output of the board 
% 
% @par LICENCE
% @verbatim
% Copyright (C) 2009 - 2013 ADDI-DATA GmbH
% 
% ADDI-DATA GmbH
% Airpark Business Center
% Airport Boulevard B210
% 77836 Rheinmnster
% Germany
% Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
% http://www.addi-data-com  |  info@addi-data.com
% @endverbatim
%%
%##protect##"FileHeader"

addpath('../MEX');

clc;                            % Clears the command window

%##protect##"Set1DigitalOutput_VariablesDeclaration"
answer = 1;
%##protect##"Set1DigitalOutput_VariablesDeclaration"


disp('**************************************************************************************');
disp('***                            Set1DigitalOutput sample                            ***');
disp('**************************************************************************************');
disp('***    Sets one digital output of the board                                        ***');
disp('**************************************************************************************');

disp (' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');
%##protect##"Set1DigitalOutput_AcquisitionInputs"
memoryFlag = input('Do you want to use the digital output memory (0: no, 1: yes)? ');
while ((memoryFlag < 0) || (memoryFlag > 1))
    memoryFlag = input('Do you want to use the digital output memory (0: no, 1: yes)? ');
end
%##protect##"Set1DigitalOutput_AcquisitionInputs"

disp (' ');

%##protect##"Set1DigitalOutput_Start"
%##protect##"Set1DigitalOutput_Start"

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

%##protect##"Set1DigitalOutput_Body"
% Sets all the digital outputs off
[returnError] = i_PCIe1516_mexSetAllDigitalOutputs(handle, 0);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

% Set the digital output memory flag
if (memoryFlag == 0)
    [returnError] = i_PCIe1516_mexSetDigitalOutputMemoryOff(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end
else
    [returnError] = i_PCIe1516_mexSetDigitalOutputMemoryOn(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end
end

while (answer == 1)
    disp(' ');

    channel = input('Select the channel you want to use (0 to 7): ');
    while ((channel < 0) || (channel > 7))
        channel = input('Select the channel you want to use (0 to 7): ');
    end
    
    if (memoryFlag == 1)
        setReset = input('Do you want to set or reset this channel (0: reset, 1: set)? ');
        while ((setReset < 0) || (setReset > 1))
            setReset = input('Do you want to set or reset this channel (0: reset, 1: set)? ');
        end
    end
    
    if ((memoryFlag == 1) && (setReset == 0))
        % Sets the digital output off
        [returnError] = i_PCIe1516_mexSet1DigitalOutputOff(handle, channel);
        if (returnError ~= 0)
            [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
            break;
        end
    else
        % Sets the digital output on
        [returnError] = i_PCIe1516_mexSet1DigitalOutputOn(handle, channel);
        if (returnError ~= 0)
            [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
            break;
        end
    end
    
    % Displays the digital outputs status
    [returnError, tempStatus] = i_PCIe1516_mexGet8DigitalOutputsStatus(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
    
    for i = 1:1:8
        % Separates the values of each channel
        x = bitand(tempStatus, bitshift(1,(i-1)));
        if (x == 0)
            outputStatus(1, i) = 0;
        else
            outputStatus(1, i) = 1;
        end
    end
    
    disp('/---------------------------------------------------------------------------------------\');
    disp('| Output 0 | Output 1 | Output 2 | Output 3 | Output 4 | Output 5 | Output 6 | Output 7 |');
    disp('|---------------------------------------------------------------------------------------|');
    toDisp = '|     %d    |     %d    |     %d    |     %d    |     %d    |     %d    |     %d    |     %d    |\n';
    fprintf(toDisp, outputStatus(1, 1), outputStatus(1, 2), outputStatus(1, 3), outputStatus(1, 4), outputStatus(1, 5), outputStatus(1, 6), outputStatus(1, 7), outputStatus(1, 8));
    disp('\---------------------------------------------------------------------------------------/');
    
    answer = input('Do you want to continue or stop the sample (0: stop, 1: continue)? ');
	while ((answer < 0) || (answer > 1))
		answer = input('Do you want to continue or stop the sample (0: stop, 1: continue)? ');
    end
end
%##protect##"Set1DigitalOutput_Body"

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
