%##protect##"FileHeader"
%%
% @file SetAllDigitalOutputs.m
% 
% @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
% @date    Creation: 11.02.2013
% @date    $LastChangedDate: 2013-02-18 15:44:16 +0100 (Mo, 18. Feb 2013) $
% @version $LastChangedRevision: 3873 $
% 
% @par DESCRIPTION
% Sets all the digital outputs of the board without using the digital output memory 
% 
% @par LICENCE
% @verbatim
% Copyright (C) 2009 - 2013 ADDI-DATA GmbH
% 
% ADDI-DATA GmbH
% Airpark Business Center
% Airport Boulevard B210
% 77836 Rheinmnster
% Germany
% Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
% http://www.addi-data-com  |  info@addi-data.com
% @endverbatim
%%
%##protect##"FileHeader"

addpath('../MEX');

clc;                            % Clears the command window

%##protect##"SetAllDigitalOutputs_VariablesDeclaration"
answer = 1;
tempStatus = 0;
outputStatus = zeros(1, 8);
%##protect##"SetAllDigitalOutputs_VariablesDeclaration"


disp('**************************************************************************************');
disp('***                          SetAllDigitalOutputs sample                           ***');
disp('**************************************************************************************');
disp('***    Sets all the digital outputs of the board without using the digital         ***');
disp('***    output memory                                                               ***');
disp('**************************************************************************************');

disp (' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');
%##protect##"SetAllDigitalOutputs_AcquisitionInputs"
%##protect##"SetAllDigitalOutputs_AcquisitionInputs"

disp (' ');

%##protect##"SetAllDigitalOutputs_Start"
%##protect##"SetAllDigitalOutputs_Start"

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

%##protect##"SetAllDigitalOutputs_Body"
% Sets all the digital outputs off
[returnError] = i_PCIe1516_mexSetAllDigitalOutputs(handle, 0);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

while (answer == 1)
    disp(' ');

    value = input('Which value do you want to set on the digital output (0 to 255): ');
    while ((value < 0) || (value > 255))
        value = input('Which value do you want to set on the digital output (0 to 255): ');
    end
    
    % Sets the digital value on the outputs
    [returnError] = i_PCIe1516_mexSetAllDigitalOutputs(handle, value);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
    
    % Displays the digital outputs status
    [returnError, tempStatus] = i_PCIe1516_mexGet8DigitalOutputsStatus(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        break;
    end
    
    for i = 1:1:8
        % Separates the values of each channel
        x = bitand(tempStatus, bitshift(1,(i-1)));
        if (x == 0)
            outputStatus(1, i) = 0;
        else
            outputStatus(1, i) = 1;
        end
    end
    
    disp('/---------------------------------------------------------------------------------------\');
    disp('| Output 0 | Output 1 | Output 2 | Output 3 | Output 4 | Output 5 | Output 6 | Output 7 |');
    disp('|---------------------------------------------------------------------------------------|');
    toDisp = '|     %d    |     %d    |     %d    |     %d    |     %d    |     %d    |     %d    |     %d    |\n';
    fprintf(toDisp, outputStatus(1, 1), outputStatus(1, 2), outputStatus(1, 3), outputStatus(1, 4), outputStatus(1, 5), outputStatus(1, 6), outputStatus(1, 7), outputStatus(1, 8));    % Allows us to display an '\n'
    disp('\---------------------------------------------------------------------------------------/');
    
    answer = input('Do you want to continue or stop the sample (0: stop, 1: continue)? ');
	while ((answer < 0) || (answer > 1))
		answer = input('Do you want to continue or stop the sample (0: stop, 1: continue)? ');
	end
end

% Sets all the digital outputs off
[returnError] = i_PCIe1516_mexSetAllDigitalOutputs(handle, 0);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
%##protect##"SetAllDigitalOutputs_Body"

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
