addpath('MEX');

clc;                                    % Clears the command window
clear;                                  % Clears the workspace
% Declaration of the variables
inputs = zeros(8, 7000, 'uint16');
outputs = zeros(8, 7000, 'uint16');
risingEdge = zeros(8, 1);
time = zeros(1, 7000);                  % Time base for displaying the values
labelY = ['0', '1', '2', '3', '4', '5', '6', '7'];
t = 0;


disp('%***************************************************%');
disp('%*******    Sample for the PCIe1516 board    *******%');
disp('%***************************************************%');
disp('%**  A first rising edge on the input x sets its  **%');
disp('%**  corresponding output x, and a second rising  **%');
disp('%**  edge on it resets this output x.             **%');
disp('%***************************************************%');

% The following line displays an empty line
disp(' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');

disp(' ');

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

% Sets all the digital outputs off
[returnError] = i_PCIe1516_mexSetAllDigitalOutputs(handle, 0);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

% Set the digital output memory on
[returnError] = i_PCIe1516_mexSetDigitalOutputMemoryOn(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

disp('Acquisition in progress...');
disp('Please wait');

time(1) = 0;
for i = 1:1:7000       % With a value of 7000, the acquisition time lasts around 10 sec
        t1 = clock;

        for j = 1:1:8
            if (risingEdge(j) == 2)
                risingEdge(j) = 0;
            end

            % Acquisition of the value of each digital input
            [returnError, inputs(j, i)] = i_PCIe1516_mexRead1DigitalInput(handle, (j-1));
            if (returnError ~= 0)
                [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
                break;
            end
            if (t ~= 0)     % The first time we pass in the loop, the input(j, (i-1)) value doesn't exist yet
                if ((inputs (j, (i-1)) == 0) && (inputs (j, i)) ~= 0)
                    risingEdge(j) = risingEdge(j) + 1;

                    % First rising
                    if (risingEdge(j) == 1)
                        [returnError] = i_PCIe1516_mexSet1DigitalOutputOn(handle, (j-1));
                        if (returnError ~= 0)
                            [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
                            break;
                        end
                    elseif (risingEdge(j) == 2)
                        [returnError] = i_PCIe1516_mexSet1DigitalOutputOff(handle, (j-1));
                        if (returnError ~= 0)
                            [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
                            break;
                        end
                    end
                end
            end
            % Acquisition of the status of the digital outputs
            [returnError, outputs(j, i)] = i_PCIe1516_mexGet1DigitalOutputStatus(handle, (j-1));
            if (returnError ~= 0)
                [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
                break;
            end
        end

        tic;                        % Wait for 1 ms (the pause function doesn't allow us to wait less than 1 sec)
        while toc < 0.001
        end

        t2 = clock;
        if (i >= 2)
            time(i) = time(i-1) + etime(t2, t1);
        end

        t = 1;
end

% Displays the values of the 8 digital inputs followed by the 8 digital outputs on separated figures:
k = 1;
for j = 1:1:8
    subplot(16,1,k);
    plot(time, inputs(j, :), 'r');      % Display the input x
    if (j == 1)
        title('Status of the digital inputs and outputs', 'Fontsize', 10, 'Color', 'blue');
    end
    set(gca, 'XTick', []);
    ylim([-0.25 1.25]);
    ylabel(labelY(j));
    k = k + 1;
    subplot(16,1,k);
    plot(time, outputs(j, :), 'b');     % Display the output x
    set(gca, 'XTick', []);
    ylim([-0.25 1.25]);
    k = k + 1;
end
subplot(16,1,15);
plot(time, inputs(8, :), 'r');          % Display the input 7
set(gca, 'XTick', []);
ylim([-0.25 1.25]);
ylabel(labelY(8));
subplot(16,1,16);
plot(time, outputs(8, :), 'b');         % Display the output 7
xlabel('Time in secondes');
ylim([-0.25 1.25]);

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
