%##protect##"FileHeader"
%%
% @file Watchdog.m
% 
% @authors S. Beuque, C. Guinot, J. Krauth, N. Reibel, J. Rose, L. Sartory, S. Weber
% @date    Creation: 11.02.2013
% @date    $LastChangedDate: 2013-02-18 15:44:16 +0100 (Mo, 18. Feb 2013) $
% @version $LastChangedRevision: 3873 $
% 
% @par DESCRIPTION
% This sample show you how to use the watchdog of the board 
% 
% @par LICENCE
% @verbatim
% Copyright (C) 2009 - 2013 ADDI-DATA GmbH
% 
% ADDI-DATA GmbH
% Airpark Business Center
% Airport Boulevard B210
% 77836 Rheinmnster
% Germany
% Tel: +49(0)7229/1847-0    |  Fax: +49(0)7229/1847-200
% http://www.addi-data-com  |  info@addi-data.com
% @endverbatim
%%
%##protect##"FileHeader"

addpath('../MEX');

clc;                            % Clears the command window

%##protect##"Watchdog_VariablesDeclaration"
answer = 1;
watchdogValue = 1;
oldWatchdogValue = 0;
%##protect##"Watchdog_VariablesDeclaration"


disp('**************************************************************************************');
disp('***                                Watchdog sample                                 ***');
disp('**************************************************************************************');
disp('***    This sample show you how to use the watchdog of the board                   ***');
disp('**************************************************************************************');

disp (' ');

% Acquisition of the inputs parameters
index = input('Select the index of the board: ');
timeBase = input('Select a time base (0: us, 1: ms, 2: sec): ');
while ((timeBase < 0) && (timeBase > 2))
    timeBase = input('Select a time basis (0: us, 1: ms, 2: sec): ');
end
reloadValue = input('Enter a reload value (0 to 4095): ');
while ((reloadValue < 0) && (reloadValue > 4095))
     reloadValue = input('Enter a reload value (0 to 4095): ');
end
%##protect##"Watchdog_AcquisitionInputs"
%##protect##"Watchdog_AcquisitionInputs"

disp (' ');

%##protect##"Watchdog_Start"
%##protect##"Watchdog_Start"

% Open the board
[returnError, handle] = i_PCIe1516_mexOpenBoardViaIndex(index);
if (returnError ~= 0)
	[errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end

%##protect##"Watchdog_Body"
% Starts the watchdog
[returnError] = i_PCIe1516_mexInitAndStartWatchdog(handle, reloadValue, timeBase);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
while (answer == 1)
    % Sets all the digital outputs
    [returnError] = i_PCIe1516_mexSetAllDigitalOutputs(handle, 255);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end

    % Waits for an input from the keyboard
    toDisp = '\n****    Press the key T to trigger the watchdog    ****\n****         and then press the enter key          ****\n';
    fprintf(toDisp);
    disp(' ');
    trigger = input('Wait for triggering the watchdog: ', 's');
    while ((trigger ~= 'T') && (trigger ~= 't'))
        trigger = input('Wait for triggering the watchdog: ', 's');
    end
    
    [returnError] = i_PCIe1516_mexTriggerWatchdog(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end

    % Reads the watchdog value
    [returnError, watchdogValue] = i_PCIe1516_mexReadWatchdogValue(handle);
    if (returnError ~= 0)
        [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
    end
    while (watchdogValue ~= 0)
        % Reads the watchdog value
        [returnError, watchdogValue] = i_PCIe1516_mexReadWatchdogValue(handle);
        if (returnError ~= 0)
            [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
        end
        if (oldWatchdogValue ~= watchdogValue)
            toDisp = '\nWatchdogValue: %d';
            fprintf(toDisp, watchdogValue);
        end
        oldWatchdogValue = watchdogValue;
    end

    fprintf('\n\n');
    answer = input('Do you want to start again (0: no, 1: yes)? ');
    fprintf('\n\n');    
end

% Stops the watchdog
[returnError] = i_PCIe1516_mexStopAndReleaseWatchdog(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
%##protect##"Watchdog_Body"

disp(' ');
% Close the board
[returnError] = i_PCIe1516_mexCloseBoard(handle);
if (returnError ~= 0)
    [errorMessage] = pc_PCIe1516_mexGetLastError(handle);
end
disp('End of the sample.');
disp(' ');
